==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/action.acp_overview.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_overview extends XFAction {
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  XFUI::html_head('{:acp_overview}');
  $ucfg = array('main_enable','main_version');
  $rcfg = XF::get_cfg('*');
  $cfg = array();
    foreach ( $rcfg as $k=>$v ){
      if ( in_array($k,$ucfg,true) )
      $cfg[$k] = $v;
    }
  unset($rcfg,$ucfg);

  $stsk = XF::sql_query("SELECT * FROM ".XF::tbl('config_task')."
  WHERE ct_active = true ORDER BY ct_time_last DESC LIMIT 1 OFFSET 0",'',__METHOD__,__LINE__);
  $task = $stsk->fetchObject();
  $task = ( is_object($task) ) ? (array)$task : array();
    if ( isset($task['ct_time_last']) )
    $task['next_run'] = intval($task['ct_time_last']+$task['ct_time_interval']);
  $stsk->closeCursor();

    if ( XF::get_cfg('log_enable') ){
    $data = array();
    $group = XF::get_group('*');
    $slog = XF::sql_query("SELECT * FROM ".XF::tbl('log')." WHERE l_index_month = '".gmdate('m')."' AND l_index_year = '".gmdate('Y')."'
    ORDER BY l_time DESC LIMIT 15 OFFSET 0",'',__METHOD__,__LINE__);
      while ( $r = $slog->fetchObject() ){
      $action = explode(',',$r->l_action);
      $msg = explode(chr(10),$r->l_text);
      $user = XF::get_user($r->l_u_id);
      $r->l_ip = long2ip($r->l_ip);
      $r->u_name = $user['u_name'];
      $r->g_name = $group[$user['u_group']]['g_name'];
      $r->g_color = $group[$user['u_group']]['g_color'];
      $r->level_str = 'log_level_'.$r->l_level;
      $r->method = $action[0];
      $r->action = $action[1];
        if ( isset($msg[0]) && !empty($msg[0]) ){
          foreach ( $msg as $k=>$v )
          $msg[$k] = '<span class="xf_alv_key">'.substr($v,0,strpos($v,'=')).'</span>=<span class="xf_alv_value">'.substr($v,strpos($v,'=')+2,-1).'</span>';
        }
        else
        $msg = array();
      $r->l_text_f = implode('<br />',$msg);
      unset($r->l_action);
      $data[] = (array)$r;
      }
    $slog->closeCursor();
    XF::$tpl->clear_cache('acp_log_results.tpl');
    XF::$tpl->assign('log_listing',$data);
    $log = trim(XF::$tpl->fetch('acp_log_results.tpl'));
    XF::reset_tpl();
    unset($data,$group);
    }
    else
    $log = false;

    if ( !XF::$tpl->is_cached('acp_overview_statistic.tpl') ){
    $stat = array();
    $today = gmmktime(0,0,0,gmdate('m'),gmdate('d'),gmdate('y'));
    $susr = XF::sql_query("SELECT COUNT(u_id) AS user_count FROM ".XF::tbl('user')." WHERE u_time_registration > :today",array(
    'today'=>array($today,'int')),__METHOD__,__LINE__);
    $r = $susr->fetchObject();
    $stat['user_registered_today'] = ( is_object($r) ) ? intval($r->user_count) : 0;
    $susr->closeCursor();
    $susr = XF::sql_query("SELECT COUNT(ur_class) AS request_count FROM ".XF::tbl('user_request')."
    WHERE ur_class IN ('ACTIVATE_ACCOUNT','ACTIVATE_PASSWORD')",'',__METHOD__,__LINE__);
    $r = $susr->fetchObject();
    $stat['user_request_total'] = ( is_object($r) ) ? intval($r->request_count) : 0;
    $susr->closeCursor();
    $susr = XF::sql_query("SELECT COUNT(u_id) AS user_count,u_active FROM ".XF::tbl('user')." GROUP BY u_active",array(
    'today'=>array($today,'int')),__METHOD__,__LINE__);
      while ( $r = $susr->fetchObject() ){
        if ( (bool)$r->u_active )
        $stat['user_account_enabled'] = intval($r->user_count);
        else
        $stat['user_account_disabled'] = intval($r->user_count);
      }
    $stat['user_total'] = ( isset($stat['user_account_enabled']) && isset($stat['user_account_disabled']) )
    ? intval($stat['user_account_enabled']+$stat['user_account_disabled']) : 0;
    $susr->closeCursor();
    $spst = XF::sql_query("SELECT COUNT(p_id) AS post_count,p_approved FROM ".XF::tbl('post_meta')." GROUP BY p_approved",'',__METHOD__,__LINE__);
      while ( $r = $spst->fetchObject() ){
        if ( (bool)$r->p_approved )
        $stat['post_visible'] = intval($r->post_count);
        else
        $stat['post_hidden'] = intval($r->post_count);
      }
      if ( !isset($stat['post_hidden']) )
      $stat['post_hidden'] = 0;
    $stat['post_total'] = ( isset($stat['post_visible']) && isset($stat['post_hidden']) )
    ? intval($stat['post_visible']+$stat['post_hidden']) : 0;
    $spst->closeCursor();
    XF::$tpl->cache_lifetime = 1800;
    XF::$tpl->assign('statistic_data',$stat);
    unset($today,$r);
    }
  $stat = XF::$tpl->fetch('acp_overview_statistic.tpl');
  XF::reset_tpl();

    if ( !XF::$tpl->is_cached('acp_overview_request.tpl') ){
    $cg = XF::vault_query('current_group_id');
    $pp = XFUI::get_post_prefix_list(true);
    $group = XF::get_group('*');
    $lpr = array();
      foreach ( $pp as $k=>$v ){
        if ( !$v['pp_list_as_request'] )
        unset($pp[$k]);
      }
    $ppi = array_keys($pp);
    $ru = ( $group[$cg]['g_read_unapproved'] ) ? '' : 'AND p_approved = 1';
    $slpr = XF::sql_query("SELECT p_id,p_u_id,p_pp_id,p_time,p_subject FROM ".XF::tbl('post_meta')."
    WHERE p_pp_id IN (".implode(',',$ppi).") AND p_closed = false $ru ORDER BY p_time DESC",'',__METHOD__,__LINE__);
      while ( $r = $slpr->fetchObject() ){
      $u = XF::get_user($r->p_u_id);
      $r->p_subject = '['.$pp[$r->p_pp_id]['pp_name'].'] '.$r->p_subject;
      $r->u_name = $u['u_name'];
      $r->g_name = $group[$u['u_group']]['g_name'];
      $r->g_color = $group[$u['u_group']]['g_color'];
      $lpr[] = (array)$r;
      }
    $slpr->closeCursor();
    XF::$tpl->cache_lifetime = 600;
    XF::$tpl->assign('pending_request',$lpr);
    unset($cg,$pp,$group,$k,$v,$r,$ppi,$ru,$u,$lpr);
    }
  $pr = XF::$tpl->fetch('acp_overview_request.tpl');
  XF::reset_tpl();

  XF::$tpl->clear_cache('acp_overview.tpl');
  XF::$tpl->assign('database_too_old',(XF::DATABASE_VERSION > XF::get_cfg('main_version'))?true:false);
  XF::$tpl->assign('version',XF::VERSION);
  XF::$tpl->assign('statistic',$stat);
  XF::$tpl->assign('pending_request',$pr);
  XF::$tpl->assign('config_vars',$cfg);
  XF::$tpl->assign('task',$task);
  XF::$tpl->assign('log',$log);
  XF::$tpl->display('acp_overview.tpl');
  XFUI::html_foot();
  return true;
  }

  /**
  * @since 1.0.0
  */
  protected function ajax($input){}

  /**
  * executives overview (starts in run() directly)
  * @since 1.0.0
  */
  public function execute(){}

}
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/action.acp_overview.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_overview extends XFAction {
const USE_TAN = false;
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  $new_version_available = false;
  $updchk = XF::sanitize_var(XF::ifset('GET','updchk',0),'booli');
  $this->gpc = array('update_check'=>$updchk);
  unset($updchk);

    if ( $this->gpc['update_check'] === 1 ){
    $reply = '';
    $found = array();
    $host = 'freesoftware.net23.net';
    $required = array('version'=>null,'uri'=>null);
    $request = "GET /larusboard/latest_version HTTP/1.0\r\nHost: $host\r\nAccept: text/plain\r\nConnection: close\r\n\r\n";
    $sock = fsockopen($host,80);
      if ( $sock ){
      fputs($sock,$request);
      $reply = fread($sock,2048);
      fclose($sock);
      preg_match_all('/([a-z]+)=(.*)/',substr($reply,strpos($reply,"\r\n\r\n")+4),$reply,PREG_SET_ORDER);
        if ( sizeof($reply) > 0 ){
          foreach ( $reply as $v ){
          $found[$v[1]] = $v[2];
          unset($required[$v[1]]);
          }
        }
        if ( sizeof($required) === 0 && version_compare(XF::VERSION,$found['version'],'<') )
        $new_version_available = sprintf(XFUI::i18n('new_forum_software_version_available'),$found['uri'],$found['version']);
      }
    unset($host,$sock,$request,$reply,$required,$found);
    }

  $ucfg = array('main_enable','main_version');
  $rcfg = XF::get_cfg('*');
  $cfg = array();
    foreach ( $rcfg as $k=>$v ){
      if ( in_array($k,$ucfg,true) )
      $cfg[$k] = $v;
    }
  unset($rcfg,$ucfg);

  $stsk = XF::sql_query("SELECT * FROM ".XF::tbl('config_task')."
  WHERE ct_active = true ORDER BY ct_time_last DESC LIMIT 1 OFFSET 0",'',__METHOD__,__LINE__);
  $task = $stsk->fetchObject();
  $task = ( is_object($task) ) ? (array)$task : array();
    if ( isset($task['ct_time_last']) )
    $task['next_run'] = intval($task['ct_time_last']+$task['ct_time_interval']);
  $stsk->closeCursor();

    if ( XF::get_cfg('log_enable') ){
    $data = array();
    $group = XF::get_group('*');
    $slog = XF::sql_query("SELECT * FROM ".XF::tbl('log')." WHERE l_index_month = '".gmdate('m')."' AND l_index_year = '".gmdate('Y')."'
    ORDER BY l_time DESC LIMIT 15 OFFSET 0",'',__METHOD__,__LINE__);
      while ( $r = $slog->fetchObject() ){
      $action = explode(',',$r->l_action);
      $msg = explode(chr(10),$r->l_text);
      $user = XF::get_user($r->l_u_id);
      $r->l_ip = long2ip($r->l_ip);
      $r->u_name = $user['u_name'];
      $r->g_name = $group[$user['u_group']]['g_name'];
      $r->g_color = $group[$user['u_group']]['g_color'];
      $r->level_str = 'log_level_'.$r->l_level;
      $r->method = $action[0];
      $r->action = $action[1];
        if ( isset($msg[0]) && !empty($msg[0]) ){
          foreach ( $msg as $k=>$v )
          $msg[$k] = '<span class="xf_alv_key">'.substr($v,0,strpos($v,'=')).'</span>=<span class="xf_alv_value">'.substr($v,strpos($v,'=')+2,-1).'</span>';
        }
        else
        $msg = array();
      $r->l_text_f = implode('<br />',$msg);
      unset($r->l_action);
      $data[] = (array)$r;
      }
    $slog->closeCursor();
    XF::$tpl->clear_cache('acp_log_results.tpl');
    XF::$tpl->assign('log_listing',$data);
    $log = trim(XF::$tpl->fetch('acp_log_results.tpl'));
    XF::reset_tpl();
    unset($data,$group);
    }
    else
    $log = false;

    if ( !XF::$tpl->is_cached('acp_overview_statistic.tpl') ){
    $stat = array();
    $today = gmmktime(0,0,0,gmdate('m'),gmdate('d'),gmdate('y'));
    $susr = XF::sql_query("SELECT COUNT(u_id) AS user_count FROM ".XF::tbl('user')." WHERE u_time_registration > :today",array(
    'today'=>array($today,'int')),__METHOD__,__LINE__);
    $r = $susr->fetchObject();
    $stat['user_registered_today'] = ( is_object($r) ) ? intval($r->user_count) : 0;
    $susr->closeCursor();
    $susr = XF::sql_query("SELECT COUNT(ur_class) AS request_count FROM ".XF::tbl('user_request')."
    WHERE ur_class IN ('ACTIVATE_ACCOUNT','ACTIVATE_PASSWORD')",'',__METHOD__,__LINE__);
    $r = $susr->fetchObject();
    $stat['user_request_total'] = ( is_object($r) ) ? intval($r->request_count) : 0;
    $susr->closeCursor();
    $susr = XF::sql_query("SELECT COUNT(u_id) AS user_count,u_active FROM ".XF::tbl('user')." GROUP BY u_active",array(
    'today'=>array($today,'int')),__METHOD__,__LINE__);
      while ( $r = $susr->fetchObject() ){
        if ( (bool)$r->u_active )
        $stat['user_account_enabled'] = intval($r->user_count);
        else
        $stat['user_account_disabled'] = intval($r->user_count);
      }
    $stat['user_total'] = ( isset($stat['user_account_enabled']) && isset($stat['user_account_disabled']) )
    ? intval($stat['user_account_enabled']+$stat['user_account_disabled']) : 0;
    $susr->closeCursor();
    $spst = XF::sql_query("SELECT COUNT(p_id) AS post_count,p_approved FROM ".XF::tbl('post_meta')." GROUP BY p_approved",'',__METHOD__,__LINE__);
      while ( $r = $spst->fetchObject() ){
        if ( (bool)$r->p_approved )
        $stat['post_visible'] = intval($r->post_count);
        else
        $stat['post_hidden'] = intval($r->post_count);
      }
      if ( !isset($stat['post_hidden']) )
      $stat['post_hidden'] = 0;
    $stat['post_total'] = ( isset($stat['post_visible']) && isset($stat['post_hidden']) )
    ? intval($stat['post_visible']+$stat['post_hidden']) : 0;
    $spst->closeCursor();
    XF::$tpl->cache_lifetime = 1800;
    XF::$tpl->assign('statistic_data',$stat);
    unset($today,$r);
    }
  $stat = XF::$tpl->fetch('acp_overview_statistic.tpl');
  XF::reset_tpl();

    if ( !XF::$tpl->is_cached('acp_overview_request.tpl') ){
    $cg = XF::vault_query('current_group_id');
    $pp = XFUI::get_post_prefix_list(true);
    $group = XF::get_group('*');
    $lpr = array();
      foreach ( $pp as $k=>$v ){
        if ( !$v['pp_list_as_request'] )
        unset($pp[$k]);
      }
    $ppi = array_keys($pp);
    $ru = ( $group[$cg]['g_read_unapproved'] ) ? '' : 'AND p_approved = 1';
    $slpr = XF::sql_query("SELECT p_id,p_u_id,p_pp_id,p_time,p_subject FROM ".XF::tbl('post_meta')."
    WHERE p_pp_id IN (".implode(',',$ppi).") AND p_closed = false $ru ORDER BY p_time DESC",'',__METHOD__,__LINE__);
      while ( $r = $slpr->fetchObject() ){
      $u = XF::get_user($r->p_u_id);
      $r->p_subject = '['.$pp[$r->p_pp_id]['pp_name'].'] '.$r->p_subject;
      $r->u_name = $u['u_name'];
      $r->g_name = $group[$u['u_group']]['g_name'];
      $r->g_color = $group[$u['u_group']]['g_color'];
      $lpr[] = (array)$r;
      }
    $slpr->closeCursor();
    XF::$tpl->cache_lifetime = 600;
    XF::$tpl->assign('pending_request',$lpr);
    unset($cg,$pp,$group,$k,$v,$r,$ppi,$ru,$u,$lpr);
    }
  $pr = XF::$tpl->fetch('acp_overview_request.tpl');
  XF::reset_tpl();

  XFUI::html_head('{:acp_overview}');
  XF::$tpl->clear_cache('acp_overview.tpl');
  XF::$tpl->assign('database_too_old',(XF::DATABASE_VERSION > XF::get_cfg('main_version'))?true:false);
  XF::$tpl->assign('new_version',$new_version_available);
  XF::$tpl->assign('version',array('software'=>XF::VERSION,'php'=>PHP_VERSION,'database'=>__XF_SQL_ENGINE.' '.XF::$sql->getAttribute(PDO::ATTR_SERVER_VERSION)));
  XF::$tpl->assign('statistic',$stat);
  XF::$tpl->assign('pending_request',$pr);
  XF::$tpl->assign('config_vars',$cfg);
  XF::$tpl->assign('task',$task);
  XF::$tpl->assign('log',$log);
  XF::$tpl->display('acp_overview.tpl');
  XFUI::html_foot();
  return true;
  }

  /**
  * @since 1.0.0
  */
  protected function ajax($input){}

  /**
  * executives overview (starts in run() directly)
  * @since 1.0.0
  */
  public function execute(){}

}
?>
